---
title: Brute Neighbors
id: brute-neighbors
layout: default.haml
author: Henry David Thoreau
date: 2018-04-15
chapter: 12
category: animals
kind: article
---

## Brute Neighbors

Sometimes I had a companion in my fishing, who came through the village
to my house from the other side of the town, and the catching of the
dinner was as much a social exercise as the eating of it.

_Hermit._ I wonder what the world is doing now. I have not heard so
much as a locust over the sweet-fern these three hours. The pigeons are
all asleep upon their roosts,—no flutter from them. Was that a farmer’s
noon horn which sounded from beyond the woods just now? The hands are
coming in to boiled salt beef and cider and Indian bread. Why will men
worry themselves so? He that does not eat need not work. I wonder how
much they have reaped. Who would live there where a body can never
think for the barking of Bose? And O, the housekeeping! to keep bright
the devil’s door-knobs, and scour his tubs this bright day! Better not
keep a house. Say, some hollow tree; and then for morning calls and
dinner-parties! Only a woodpecker tapping. O, they swarm; the sun is
too warm there; they are born too far into life for me. I have water
from the spring, and a loaf of brown bread on the shelf.—Hark! I hear a
rustling of the leaves. Is it some ill-fed village hound yielding to
the instinct of the chase? or the lost pig which is said to be in these
woods, whose tracks I saw after the rain? It comes on apace; my sumachs
and sweet-briers tremble.—Eh, Mr. Poet, is it you? How do you like the
world to-day?

_Poet._ See those clouds; how they hang! That’s the greatest thing I
have seen to-day. There’s nothing like it in old paintings, nothing
like it in foreign lands,—unless when we were off the coast of Spain.
That’s a true Mediterranean sky. I thought, as I have my living to get,
and have not eaten to-day, that I might go a-fishing. That’s the true
industry for poets. It is the only trade I have learned. Come, let’s
along.

_Hermit._ I cannot resist. My brown bread will soon be gone. I will go
with you gladly soon, but I am just concluding a serious meditation. I
think that I am near the end of it. Leave me alone, then, for a while.
But that we may not be delayed, you shall be digging the bait
meanwhile. Angle-worms are rarely to be met with in these parts, where
the soil was never fattened with manure; the race is nearly extinct.
The sport of digging the bait is nearly equal to that of catching the
fish, when one’s appetite is not too keen; and this you may have all to
yourself to-day. I would advise you to set in the spade down yonder
among the ground-nuts, where you see the johnswort waving. I think that
I may warrant you one worm to every three sods you turn up, if you look
well in among the roots of the grass, as if you were weeding. Or, if
you choose to go farther, it will not be unwise, for I have found the
increase of fair bait to be very nearly as the squares of the
distances.

_Hermit alone._ Let me see; where was I? Methinks I was nearly in this
frame of mind; the world lay about at this angle. Shall I go to heaven
or a-fishing? If I should soon bring this meditation to an end, would
another so sweet occasion be likely to offer? I was as near being
resolved into the essence of things as ever I was in my life. I fear my
thoughts will not come back to me. If it would do any good, I would
whistle for them. When they make us an offer, is it wise to say, We
will think of it? My thoughts have left no track, and I cannot find the
path again. What was it that I was thinking of? It was a very hazy day.
I will just try these three sentences of Con-fut-see; they may fetch
that state about again. I know not whether it was the dumps or a
budding ecstasy. Mem. There never is but one opportunity of a kind.

_Poet._ How now, Hermit, is it too soon? I have got just thirteen whole
ones, beside several which are imperfect or undersized; but they will
do for the smaller fry; they do not cover up the hook so much. Those
village worms are quite too large; a shiner may make a meal off one
without finding the skewer.

_Hermit._ Well, then, let’s be off. Shall we to the Concord? There’s
good sport there if the water be not too high.



Why do precisely these objects which we behold make a world? Why has
man just these species of animals for his neighbors; as if nothing but
a mouse could have filled this crevice? I suspect that Pilpay & Co.
have put animals to their best use, for they are all beasts of burden,
in a sense, made to carry some portion of our thoughts.

The mice which haunted my house were not the common ones, which are
said to have been introduced into the country, but a wild native kind
not found in the village. I sent one to a distinguished naturalist, and
it interested him much. When I was building, one of these had its nest
underneath the house, and before I had laid the second floor, and swept
out the shavings, would come out regularly at lunch time and pick up
the crumbs at my feet. It probably had never seen a man before; and it
soon became quite familiar, and would run over my shoes and up my
clothes. It could readily ascend the sides of the room by short
impulses, like a squirrel, which it resembled in its motions. At
length, as I leaned with my elbow on the bench one day, it ran up my
clothes, and along my sleeve, and round and round the paper which held
my dinner, while I kept the latter close, and dodged and played at
bopeep with it; and when at last I held still a piece of cheese between
my thumb and finger, it came and nibbled it, sitting in my hand, and
afterward cleaned its face and paws, like a fly, and walked away.

A phœbe soon built in my shed, and a robin for protection in a pine
which grew against the house. In June the partridge (_Tetrao
umbellus_,) which is so shy a bird, led her brood past my windows, from
the woods in the rear to the front of my house, clucking and calling to
them like a hen, and in all her behavior proving herself the hen of the
woods. The young suddenly disperse on your approach, at a signal from
the mother, as if a whirlwind had swept them away, and they so exactly
resemble the dried leaves and twigs that many a traveler has placed his
foot in the midst of a brood, and heard the whir of the old bird as she
flew off, and her anxious calls and mewing, or seen her trail her wings
to attract his attention, without suspecting their neighborhood. The
parent will sometimes roll and spin round before you in such a
dishabille, that you cannot, for a few moments, detect what kind of
creature it is. The young squat still and flat, often running their
heads under a leaf, and mind only their mother’s directions given from
a distance, nor will your approach make them run again and betray
themselves. You may even tread on them, or have your eyes on them for a
minute, without discovering them. I have held them in my open hand at
such a time, and still their only care, obedient to their mother and
their instinct, was to squat there without fear or trembling. So
perfect is this instinct, that once, when I had laid them on the leaves
again, and one accidentally fell on its side, it was found with the
rest in exactly the same position ten minutes afterward. They are not
callow like the young of most birds, but more perfectly developed and
precocious even than chickens. The remarkably adult yet innocent
expression of their open and serene eyes is very memorable. All
intelligence seems reflected in them. They suggest not merely the
purity of infancy, but a wisdom clarified by experience. Such an eye
was not born when the bird was, but is coeval with the sky it reflects.
The woods do not yield another such a gem. The traveller does not often
look into such a limpid well. The ignorant or reckless sportsman often
shoots the parent at such a time, and leaves these innocents to fall a
prey to some prowling beast or bird, or gradually mingle with the
decaying leaves which they so much resemble. It is said that when
hatched by a hen they will directly disperse on some alarm, and so are
lost, for they never hear the mother’s call which gathers them again.
These were my hens and chickens.

It is remarkable how many creatures live wild and free though secret in
the woods, and still sustain themselves in the neighborhood of towns,
suspected by hunters only. How retired the otter manages to live here!
He grows to be four feet long, as big as a small boy, perhaps without
any human being getting a glimpse of him. I formerly saw the raccoon in
the woods behind where my house is built, and probably still heard
their whinnering at night. Commonly I rested an hour or two in the
shade at noon, after planting, and ate my lunch, and read a little by a
spring which was the source of a swamp and of a brook, oozing from
under Brister’s Hill, half a mile from my field. The approach to this
was through a succession of descending grassy hollows, full of young
pitch-pines, into a larger wood about the swamp. There, in a very
secluded and shaded spot, under a spreading white-pine, there was yet a
clean, firm sward to sit on. I had dug out the spring and made a well
of clear gray water, where I could dip up a pailful without roiling it,
and thither I went for this purpose almost every day in midsummer, when
the pond was warmest. Thither, too, the wood-cock led her brood, to
probe the mud for worms, flying but a foot above them down the bank,
while they ran in a troop beneath; but at last, spying me, she would
leave her young and circle round and round me, nearer and nearer till
within four or five feet, pretending broken wings and legs, to attract
my attention, and get off her young, who would already have taken up
their march, with faint wiry peep, single file through the swamp, as
she directed. Or I heard the peep of the young when I could not see the
parent bird. There too the turtle-doves sat over the spring, or
fluttered from bough to bough of the soft white-pines over my head; or
the red squirrel, coursing down the nearest bough, was particularly
familiar and inquisitive. You only need sit still long enough in some
attractive spot in the woods that all its inhabitants may exhibit
themselves to you by turns.

I was witness to events of a less peaceful character. One day when I
went out to my wood-pile, or rather my pile of stumps, I observed two
large ants, the one red, the other much larger, nearly half an inch
long, and black, fiercely contending with one another. Having once got
hold they never let go, but struggled and wrestled and rolled on the
chips incessantly. Looking farther, I was surprised to find that the
chips were covered with such combatants, that it was not a _duellum_,
but a _bellum_, a war between two races of ants, the red always pitted
against the black, and frequently two red ones to one black. The
legions of these Myrmidons covered all the hills and vales in my
wood-yard, and the ground was already strewn with the dead and dying,
both red and black. It was the only battle which I have ever witnessed,
the only battle-field I ever trod while the battle was raging;
internecine war; the red republicans on the one hand, and the black
imperialists on the other. On every side they were engaged in deadly
combat, yet without any noise that I could hear, and human soldiers
never fought so resolutely. I watched a couple that were fast locked in
each other’s embraces, in a little sunny valley amid the chips, now at
noon-day prepared to fight till the sun went down, or life went out.
The smaller red champion had fastened himself like a vice to his
adversary’s front, and through all the tumblings on that field never
for an instant ceased to gnaw at one of his feelers near the root,
having already caused the other to go by the board; while the stronger
black one dashed him from side to side, and, as I saw on looking
nearer, had already divested him of several of his members. They fought
with more pertinacity than bull-dogs. Neither manifested the least
disposition to retreat. It was evident that their battle-cry was
Conquer or die. In the mean while there came along a single red ant on
the hill-side of this valley, evidently full of excitement, who either
had despatched his foe, or had not yet taken part in the battle;
probably the latter, for he had lost none of his limbs; whose mother
had charged him to return with his shield or upon it. Or perchance he
was some Achilles, who had nourished his wrath apart, and had now come
to avenge or rescue his Patroclus. He saw this unequal combat from
afar,—for the blacks were nearly twice the size of the red,—he drew
near with rapid pace till he stood on his guard within half an inch of
the combatants; then, watching his opportunity, he sprang upon the
black warrior, and commenced his operations near the root of his right
fore-leg, leaving the foe to select among his own members; and so there
were three united for life, as if a new kind of attraction had been
invented which put all other locks and cements to shame. I should not
have wondered by this time to find that they had their respective
musical bands stationed on some eminent chip, and playing their
national airs the while, to excite the slow and cheer the dying
combatants. I was myself excited somewhat even as if they had been men.
The more you think of it, the less the difference. And certainly there
is not the fight recorded in Concord history, at least, if in the
history of America, that will bear a moment’s comparison with this,
whether for the numbers engaged in it, or for the patriotism and
heroism displayed. For numbers and for carnage it was an Austerlitz or
Dresden. Concord Fight! Two killed on the patriots’ side, and Luther
Blanchard wounded! Why here every ant was a Buttrick,—“Fire! for God’s
sake fire!”—and thousands shared the fate of Davis and Hosmer. There
was not one hireling there. I have no doubt that it was a principle
they fought for, as much as our ancestors, and not to avoid a
three-penny tax on their tea; and the results of this battle will be as
important and memorable to those whom it concerns as those of the
battle of Bunker Hill, at least.

I took up the chip on which the three I have particularly described
were struggling, carried it into my house, and placed it under a
tumbler on my window-sill, in order to see the issue. Holding a
microscope to the first-mentioned red ant, I saw that, though he was
assiduously gnawing at the near fore-leg of his enemy, having severed
his remaining feeler, his own breast was all torn away, exposing what
vitals he had there to the jaws of the black warrior, whose breastplate
was apparently too thick for him to pierce; and the dark carbuncles of
the sufferer’s eyes shone with ferocity such as war only could excite.
They struggled half an hour longer under the tumbler, and when I looked
again the black soldier had severed the heads of his foes from their
bodies, and the still living heads were hanging on either side of him
like ghastly trophies at his saddle-bow, still apparently as firmly
fastened as ever, and he was endeavoring with feeble struggles, being
without feelers and with only the remnant of a leg, and I know not how
many other wounds, to divest himself of them; which at length, after
half an hour more, he accomplished. I raised the glass, and he went off
over the window-sill in that crippled state. Whether he finally
survived that combat, and spent the remainder of his days in some Hotel
des Invalides, I do not know; but I thought that his industry would not
be worth much thereafter. I never learned which party was victorious,
nor the cause of the war; but I felt for the rest of that day as if I
had had my feelings excited and harrowed by witnessing the struggle,
the ferocity and carnage, of a human battle before my door.

Kirby and Spence tell us that the battles of ants have long been
celebrated and the date of them recorded, though they say that Huber is
the only modern author who appears to have witnessed them. “Æneas
Sylvius,” say they, “after giving a very circumstantial account of one
contested with great obstinacy by a great and small species on the
trunk of a pear tree,” adds that “‘This action was fought in the
pontificate of Eugenius the Fourth, in the presence of Nicholas
Pistoriensis, an eminent lawyer, who related the whole history of the
battle with the greatest fidelity.’ A similar engagement between great
and small ants is recorded by Olaus Magnus, in which the small ones,
being victorious, are said to have buried the bodies of their own
soldiers, but left those of their giant enemies a prey to the birds.
This event happened previous to the expulsion of the tyrant Christiern
the Second from Sweden.” The battle which I witnessed took place in the
Presidency of Polk, five years before the passage of Webster’s
Fugitive-Slave Bill.

Many a village Bose, fit only to course a mud-turtle in a victualling
cellar, sported his heavy quarters in the woods, without the knowledge
of his master, and ineffectually smelled at old fox burrows and
woodchucks’ holes; led perchance by some slight cur which nimbly
threaded the wood, and might still inspire a natural terror in its
denizens;—now far behind his guide, barking like a canine bull toward
some small squirrel which had treed itself for scrutiny, then,
cantering off, bending the bushes with his weight, imagining that he is
on the track of some stray member of the jerbilla family. Once I was
surprised to see a cat walking along the stony shore of the pond, for
they rarely wander so far from home. The surprise was mutual.
Nevertheless the most domestic cat, which has lain on a rug all her
days, appears quite at home in the woods, and, by her sly and stealthy
behavior, proves herself more native there than the regular
inhabitants. Once, when berrying, I met with a cat with young kittens
in the woods, quite wild, and they all, like their mother, had their
backs up and were fiercely spitting at me. A few years before I lived
in the woods there was what was called a “winged cat” in one of the
farm-houses in Lincoln nearest the pond, Mr. Gilian Baker’s. When I
called to see her in June, 1842, she was gone a-hunting in the woods,
as was her wont, (I am not sure whether it was a male or female, and so
use the more common pronoun,) but her mistress told me that she came
into the neighborhood a little more than a year before, in April, and
was finally taken into their house; that she was of a dark
brownish-gray color, with a white spot on her throat, and white feet,
and had a large bushy tail like a fox; that in the winter the fur grew
thick and flatted out along her sides, forming stripes ten or twelve
inches long by two and a half wide, and under her chin like a muff, the
upper side loose, the under matted like felt, and in the spring these
appendages dropped off. They gave me a pair of her “wings,” which I
keep still. There is no appearance of a membrane about them. Some
thought it was part flying-squirrel or some other wild animal, which is
not impossible, for, according to naturalists, prolific hybrids have
been produced by the union of the marten and domestic cat. This would
have been the right kind of cat for me to keep, if I had kept any; for
why should not a poet’s cat be winged as well as his horse?

In the fall the loon (_Colymbus glacialis_) came, as usual, to moult
and bathe in the pond, making the woods ring with his wild laughter
before I had risen. At rumor of his arrival all the Mill-dam sportsmen
are on the alert, in gigs and on foot, two by two and three by three,
with patent rifles and conical balls and spy-glasses. They come
rustling through the woods like autumn leaves, at least ten men to one
loon. Some station themselves on this side of the pond, some on that,
for the poor bird cannot be omnipresent; if he dive here he must come
up there. But now the kind October wind rises, rustling the leaves and
rippling the surface of the water, so that no loon can be heard or
seen, though his foes sweep the pond with spy-glasses, and make the
woods resound with their discharges. The waves generously rise and dash
angrily, taking sides with all water-fowl, and our sportsmen must beat
a retreat to town and shop and unfinished jobs. But they were too often
successful. When I went to get a pail of water early in the morning I
frequently saw this stately bird sailing out of my cove within a few
rods. If I endeavored to overtake him in a boat, in order to see how he
would manœuvre, he would dive and be completely lost, so that I did not
discover him again, sometimes, till the latter part of the day. But I
was more than a match for him on the surface. He commonly went off in a
rain.

As I was paddling along the north shore one very calm October
afternoon, for such days especially they settle on to the lakes, like
the milkweed down, having looked in vain over the pond for a loon,
suddenly one, sailing out from the shore toward the middle a few rods
in front of me, set up his wild laugh and betrayed himself. I pursued
with a paddle and he dived, but when he came up I was nearer than
before. He dived again, but I miscalculated the direction he would
take, and we were fifty rods apart when he came to the surface this
time, for I had helped to widen the interval; and again he laughed long
and loud, and with more reason than before. He manœuvred so cunningly
that I could not get within half a dozen rods of him. Each time, when
he came to the surface, turning his head this way and that, he cooly
surveyed the water and the land, and apparently chose his course so
that he might come up where there was the widest expanse of water and
at the greatest distance from the boat. It was surprising how quickly
he made up his mind and put his resolve into execution. He led me at
once to the widest part of the pond, and could not be driven from it.
While he was thinking one thing in his brain, I was endeavoring to
divine his thought in mine. It was a pretty game, played on the smooth
surface of the pond, a man against a loon. Suddenly your adversary’s
checker disappears beneath the board, and the problem is to place yours
nearest to where his will appear again. Sometimes he would come up
unexpectedly on the opposite side of me, having apparently passed
directly under the boat. So long-winded was he and so unweariable, that
when he had swum farthest he would immediately plunge again,
nevertheless; and then no wit could divine where in the deep pond,
beneath the smooth surface, he might be speeding his way like a fish,
for he had time and ability to visit the bottom of the pond in its
deepest part. It is said that loons have been caught in the New York
lakes eighty feet beneath the surface, with hooks set for trout,—though
Walden is deeper than that. How surprised must the fishes be to see
this ungainly visitor from another sphere speeding his way amid their
schools! Yet he appeared to know his course as surely under water as on
the surface, and swam much faster there. Once or twice I saw a ripple
where he approached the surface, just put his head out to reconnoitre,
and instantly dived again. I found that it was as well for me to rest
on my oars and wait his reappearing as to endeavor to calculate where
he would rise; for again and again, when I was straining my eyes over
the surface one way, I would suddenly be startled by his unearthly
laugh behind me. But why, after displaying so much cunning, did he
invariably betray himself the moment he came up by that loud laugh? Did
not his white breast enough betray him? He was indeed a silly loon, I
thought. I could commonly hear the splash of the water when he came up,
and so also detected him. But after an hour he seemed as fresh as ever,
dived as willingly and swam yet farther than at first. It was
surprising to see how serenely he sailed off with unruffled breast when
he came to the surface, doing all the work with his webbed feet
beneath. His usual note was this demoniac laughter, yet somewhat like
that of a water-fowl; but occasionally, when he had balked me most
successfully and come up a long way off, he uttered a long-drawn
unearthly howl, probably more like that of a wolf than any bird; as
when a beast puts his muzzle to the ground and deliberately howls. This
was his looning,—perhaps the wildest sound that is ever heard here,
making the woods ring far and wide. I concluded that he laughed in
derision of my efforts, confident of his own resources. Though the sky
was by this time overcast, the pond was so smooth that I could see
where he broke the surface when I did not hear him. His white breast,
the stillness of the air, and the smoothness of the water were all
against him. At length, having come up fifty rods off, he uttered one
of those prolonged howls, as if calling on the god of loons to aid him,
and immediately there came a wind from the east and rippled the
surface, and filled the whole air with misty rain, and I was impressed
as if it were the prayer of the loon answered, and his god was angry
with me; and so I left him disappearing far away on the tumultuous
surface.

For hours, in fall days, I watched the ducks cunningly tack and veer
and hold the middle of the pond, far from the sportsman; tricks which
they will have less need to practise in Louisiana bayous. When
compelled to rise they would sometimes circle round and round and over
the pond at a considerable height, from which they could easily see to
other ponds and the river, like black motes in the sky; and, when I
thought they had gone off thither long since, they would settle down by
a slanting flight of a quarter of a mile on to a distant part which was
left free; but what beside safety they got by sailing in the middle of
Walden I do not know, unless they love its water for the same reason
that I do.


